package test;

import javax.annotation.PostConstruct;
import javax.ejb.Schedule;
import javax.ejb.Singleton;
import javax.servlet.AsyncContext;
import javax.servlet.ServletResponse;
import java.io.IOException;
import java.io.PrintWriter;
import java.util.Date;
import java.util.HashSet;
import java.util.Iterator;
import java.util.Set;

/**
 * Example of silly singleton EJB.
 *
 * @author Kohsuke Kawaguchi
 */
@Singleton
public class Beacon {
    Set<AsyncContext> contexts = new HashSet<AsyncContext>();

    @PostConstruct
    public void onInitialized() {
        System.out.println("Beacon is started");
    }

    /**
     * An example of EJB timer service to have this method invoked every 2 seconds.
     */
    @Schedule(second="*/2",minute="*",hour="*")
    public void heartbeat() {
        Date now = new Date();
        System.out.println("Announcing "+now);
        for (Iterator<AsyncContext> itr = contexts.iterator(); itr.hasNext();) {
            AsyncContext context =  itr.next();
            try {
                ServletResponse rsp = context.getResponse();
                PrintWriter w = rsp.getWriter();
                w.println(now);
                rsp.flushBuffer();
            } catch (IOException e) {
                context.complete();
                itr.remove();
            }
        }
    }

    public void addContext(AsyncContext context) {
        this.contexts.add(context);
    }
}
